import enum
import os
import pathlib as pl


class LinkType(enum.Enum):
    D = 0
    H = 1
    J = 2


def mklink(src: str, dst: str, link_type: LinkType):
    """
    src - specifies the path (relative or absolute) that the new symbolic link refers to.
    dst - specifies the name of the symbolic link that is being created.
    link_type:
        LinkType.D - creates a directory symbolic link. By default, mklink creates a file symbolic link.
        LinkType.H - creates a hard link instead of a symbolic link.
        LinkType.J - creates a Directory Junction.
    """
    if link_type == LinkType.D:
        arg = "d"
    elif link_type == LinkType.H:
        arg = "h"
    elif link_type == LinkType.J:
        arg = "j"
    else:
        raise ValueError("link_type must be 0, 1, 2")
    if os.path.exists(dst):
        os.rmdir(dst)
    pl.Path(dst).parent.mkdir(parents=True, exist_ok=True)
    os.system(f'mklink /{arg} "{dst}" "{src}"')



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(name='ia256utilities',
                 version='0.4.1',
                 description='A set of useful utilities',
                 long_description=long_description,
                 long_description_content_type="text/markdown",
                 url='https://github.com/IceArrow256/ia256utilities',
                 author='IceArrow256',
                 author_email='icearrow256@gmail.com',
                 license='The Unlicense',
                 packages=['ia256utilities'],
                 zip_safe=False)



import json
import os


def load_json(path, default_dict=True):
    """
    Loads a json file and returns it as a dictionary or list
    """
    if os.path.exists(path) and os.path.isfile(path):
        with open(path, encoding="utf8") as file:
            data = json.load(file)
        file.close()
        return data
    else:
        if default_dict:
            return {}
        else:
            return []


def save_json(data, path):
    """
    Saves dictionary or list as json file
    """
    if not os.path.isdir(os.path.dirname(path)):
        os.makedirs(os.path.dirname(path))
    with open(path, 'w', encoding="utf-8") as file:
        file.write(json.dumps(data, ensure_ascii=False))
    file.close()


def save(data, path):
    """
    Saves text to a file
    """
    if not os.path.isdir(os.path.dirname(path)):
        os.makedirs(os.path.dirname(path))
    with open(path, 'w', encoding="utf-8") as file:
        file.write(data)
    file.close()


def save_binary(data, path):
    """
    Saves data as a binary file
    """
    if not os.path.isdir(os.path.dirname(path)):
        os.makedirs(os.path.dirname(path))
    with open(path, 'wb') as file:
        file.write(data)
    file.close()


def load_binary(path):
    """
    Loads data as a binary file
    """
    if os.path.exists(path) and os.path.isfile(path):
        with open(path, 'rb') as file:
            data = file.read()
        file.close()
        return data
    else:
        return None



import hashlib


def get_sha256(file_path: str) -> str:
    """
    Gets a hash(SHA-256) of a file by the path
    """
    with open(file_path, "rb") as f:
        b = f.read()
        readable_hash = hashlib.sha256(b).hexdigest()
    return readable_hash
